#! /usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Copyright 2019, Nils Hilbricht, Germany ( https://www.hilbricht.net )

This file is part of the Laborejo Software Suite ( https://www.laborejo.org ),
more specifically its template base application.

Laborejo2 is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

import logging; logging.info("import {}".format(__file__))


#Third Party
from PyQt5 import QtCore, QtGui, QtWidgets, QtOpenGL

#User modules
import engine.api as api

from qtgui.constantsAndConfigs import constantsAndConfigs #singleton

class ScoreView(QtWidgets.QGraphicsView):
    
    def __init__(self, mainWindow):
        super().__init__()        
        self.mainWindow = mainWindow                       
        
        #OpenGL has a huge positive impact on performance
        if True: #for testing
            #viewport = QtOpenGL.QGLWidget(QtOpenGL.QGLFormat(QtOpenGL.QGL.SampleBuffers))
            #viewport.format().setSwapInterval(0) #disable VSync.
            #viewport.setAutoFillBackground(False)

            viewport = QtWidgets.QOpenGLWidget()
            viewportFormat = QtGui.QSurfaceFormat()
            viewportFormat.setSwapInterval(0) #disable VSync
            #viewportFormat.setSamples(2**8) #By default, the highest number of samples available is used.
            viewportFormat.setDefaultFormat(viewportFormat)
            viewport.setFormat(viewportFormat)
            self.setViewport(viewport)        
        
        self.setAlignment(QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)                
        

        style = """
        QScrollBar:horizontal {
            border: 1px solid black;
        }

        QScrollBar::handle:horizontal {
            background: #00b2b2;
        }

        QScrollBar:vertical {
            border: 1px solid black;
        }

        QScrollBar::handle:vertical {
            background: #00b2b2;
        }
        """
        self.setStyleSheet(style)

    def centerOnCursor(self, cursorExportObject):
        raise NotImplementedError("Reimplement this in your program. Can do nothing.")        

        
    def toggleFollowPlayhead(self):
        constantsAndConfigs.followPlayhead = not constantsAndConfigs.followPlayhead
        self.mainWindow.ui.actionFollow_Playhead.setChecked(constantsAndConfigs.followPlayhead)
        #we register a callback in self init that checks constantsAndConfigs.followPlayhead
